| Home | Libraries | People | FAQ | More

### has_trivial_assign

    template <class T>
    struct has_trivial_assign : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) type with a trivial assignment-operator then inherits from true_type, otherwise inherits from false_type.

If a type has a trivial assignment-operator then the operator has the same effect as copying the bits of one object to the other: calls to the operator can be safely replaced with a call to `memcpy`.

Compiler Compatibility: Without some (as yet unspecified) help from the compiler, has_trivial_assign will never report that a user-defined class or struct has a trivial constructor; this is always safe, if possibly sub-optimal. In order to correctly handle deleted or private assignment operators, the compiler must also support C++11's `decltype`. Currently (May 2015) compilers more recent than Visual C++ 8, GCC-4.3, Greenhills 6.0, Intel-11.0, and Codegear have the necessary compiler intrinsics to ensure that this trait "just works". You may also test to see if the necessary intrinsics are available by checking to see if the macro `BOOST_HAS_TRIVIAL_ASSIGN` is defined.

C++ Standard Reference: 12.8p11.

Header: `#include <boost/type_traits/has_trivial_assign.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `has_trivial_assign<int>` inherits from `true_type`.

> `has_trivial_assign<char*>::type` is the type `true_type`.

> `has_trivial_assign<int (*)(long)>::value` is an integral constant expression that evaluates to true.

> `has_trivial_assign<MyClass>::value` is an integral constant expression that evaluates to false.

> `has_trivial_assign<T>::value_type` is the type `bool`.